IrqRequest

Struct IrqRequest 

pub struct IrqRequest { /* private fields */ }
Request parameters for an IRQ action.

Implementations

Source

impl IrqRequest

pub fn new( handler: impl FnMut(IrqContext) -> IrqReturn + Send + 'static, ) -> IrqRequest

Creates a new exclusive, global, auto-enabled IRQ request.

pub fn new_concurrent( handler: impl Fn(IrqContext) -> IrqReturn + Send + Sync + 'static, ) -> IrqRequest

Creates a new exclusive, global, auto-enabled concurrent IRQ request.

pub fn scope(self, scope: IrqScope) -> IrqRequest

Sets the IRQ scope.

pub fn affinity(self, affinity: IrqAffinity) -> IrqRequest

Sets the IRQ affinity.

pub fn execution(self, execution: IrqExecution) -> IrqRequest

Sets the action execution contract.

pub fn share_mode(self, share_mode: ShareMode) -> IrqRequest

Sets the sharing mode.

pub fn auto_enable(self, auto_enable: AutoEnable) -> IrqRequest

Sets whether the action should be enabled after request.

pub const fn auto_enable_mode(&self) -> AutoEnable

Returns whether the action should be enabled after request.