pub struct IrqRequest { /* private fields */ }Expand description
Request parameters for an IRQ action.
Implementations
Sourceimpl IrqRequest
impl IrqRequest
Sourcepub fn new(
handler: impl FnMut(IrqContext) -> IrqReturn + Send + 'static,
) -> IrqRequest
pub fn new( handler: impl FnMut(IrqContext) -> IrqReturn + Send + 'static, ) -> IrqRequest
Creates a new exclusive, global, auto-enabled IRQ request.
Sourcepub fn new_concurrent(
handler: impl Fn(IrqContext) -> IrqReturn + Send + Sync + 'static,
) -> IrqRequest
pub fn new_concurrent( handler: impl Fn(IrqContext) -> IrqReturn + Send + Sync + 'static, ) -> IrqRequest
Creates a new exclusive, global, auto-enabled concurrent IRQ request.
Sourcepub fn scope(self, scope: IrqScope) -> IrqRequest
pub fn scope(self, scope: IrqScope) -> IrqRequest
Sets the IRQ scope.
Sourcepub fn affinity(self, affinity: IrqAffinity) -> IrqRequest
pub fn affinity(self, affinity: IrqAffinity) -> IrqRequest
Sets the IRQ affinity.
Sourcepub fn execution(self, execution: IrqExecution) -> IrqRequest
pub fn execution(self, execution: IrqExecution) -> IrqRequest
Sets the action execution contract.
Sets the sharing mode.
Sourcepub fn auto_enable(self, auto_enable: AutoEnable) -> IrqRequest
pub fn auto_enable(self, auto_enable: AutoEnable) -> IrqRequest
Sets whether the action should be enabled after request.
Sourcepub const fn auto_enable_mode(&self) -> AutoEnable
pub const fn auto_enable_mode(&self) -> AutoEnable
Returns whether the action should be enabled after request.